@@ -54,6 +54,7 @@ static gboolean please_fail = FALSE;
 static gboolean disable_acceleration_check = FALSE;
 static const char *session_name = NULL;
 static GsmManager *manager = NULL;
+static char *gl_renderer = NULL;
 
 static GMainLoop *loop;
 
@@ -146,6 +147,7 @@ create_manager (void)
                 gsm_fail_whale_dialog_we_failed (FALSE, TRUE, NULL);
         }
 
+        _gsm_manager_set_renderer (manager, gl_renderer);
         gsm_manager_start (manager);
 }
 
@@ -187,7 +189,7 @@ require_dbus_session (int      argc,
                               TRUE);
 
         /* +2 for our new arguments, +1 for NULL */
-        new_argv = g_malloc ((argc + 3) * sizeof (*argv));
+        new_argv = g_malloc (argc + 3 * sizeof (*argv));
 
         new_argv[0] = "dbus-launch";
         new_argv[1] = "--exit-with-session";
@@ -220,7 +222,7 @@ check_gl (GError **error)
                 return TRUE;
         }
 
-        if (!g_spawn_sync (NULL, (char **) argv, NULL, 0, NULL, NULL, NULL, NULL,
+        if (!g_spawn_sync (NULL, (char **) argv, NULL, 0, NULL, NULL, &gl_renderer, NULL,
                            &status, error)) {
                 return FALSE;
         }
@@ -415,7 +417,9 @@ main (int argc, char **argv)
 
         /* Tell Qt to try to make Qt applications look like gnome
          */
-        gsm_util_setenv ("QT_QPA_PLATFORMTHEME", "qgnomeplatform");
+        if (g_getenv ("QT_QPA_PLATFORMTHEME") == NULL) {
+                gsm_util_setenv ("QT_QPA_PLATFORMTHEME", "qgnomeplatform");
+        }
 
         /* hack to fix keyring until we can reorder things in 3.20
          * https://bugzilla.gnome.org/show_bug.cgi?id=738205
@@ -444,6 +448,7 @@ main (int argc, char **argv)
         gsm_main ();
 
         g_clear_object (&manager);
+        g_free (gl_renderer);
 
         g_bus_unown_name (name_owner_id);
         gdm_log_shutdown ();
